Skip to contents

First-class container that holds a set of Code objects within a Theme. Use NA_character_ for name when codes are not yet sub-grouped (a "virtual" subtheme that will be populated by theme clustering).

Usage

create_subtheme(
  name = NA_character_,
  description = "",
  codes = list(),
  subthemes = list()
)

Arguments

name

Subtheme name; NA_character_ for virtual/ungrouped

description

Subtheme description

codes

List of Code S3 objects. A character vector of code names is also accepted and coerced to stub Codes for tests and non-coding contexts.

subthemes

List of nested Subtheme S3 objects (or raw lists coerced via recursive create_subtheme call). Nested subthemes support depth-N hierarchical decomposition. Empty list = leaf Subtheme (no nested children).

Value

Subtheme S3 object