Always emitted in UTC so two researchers in different timezones running the same analysis at the same wall-clock moment produce comparable run IDs.
Always emitted in UTC so two researchers in different timezones running the same analysis at the same wall-clock moment produce comparable run IDs.