Remove themes with zero assigned entries after enrichment
Source:R/12_theme_data.R
prune_empty_themes.RdCall after enrich_themes() to drop themes that no data was mapped to. Re-numbers theme IDs sequentially after pruning.
R/12_theme_data.R
prune_empty_themes.RdCall after enrich_themes() to drop themes that no data was mapped to. Re-numbers theme IDs sequentially after pruning.