Nested Subthemes were introduced so the theme algorithm can produce hierarchical decomposition (e.g. a large subtheme broken into sub-subthemes). Returns 0 for leaf Subthemes.
Nested Subthemes were introduced so the theme algorithm can produce hierarchical decomposition (e.g. a large subtheme broken into sub-subthemes). Returns 0 for leaf Subthemes.